@@ -1,18 +1,18 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::PromptIfStale; # git description: v0.039-5-gadb56aa
+package Dist::Zilla::Plugin::PromptIfStale; # git description: v0.040-10-g6731cc8
 # ABSTRACT: Check at build/release time if modules are out of date
 # KEYWORDS: prerequisites upstream dependencies modules metadata update stale
-# vim: set ts=8 sw=4 tw=78 et :
+# vim: set ts=8 sts=4 sw=4 tw=78 et :
 
-our $VERSION = '0.040';
+our $VERSION = '0.041';
 
 use Moose;
 with 'Dist::Zilla::Role::BeforeBuild',
     'Dist::Zilla::Role::AfterBuild',
     'Dist::Zilla::Role::BeforeRelease';
 
-use Moose::Util::TypeConstraints;
+use Moose::Util::TypeConstraints 'enum';
 use List::Util 1.33 qw(none any);
 use List::MoreUtils 'uniq';
 use version;
@@ -448,7 +448,7 @@ Dist::Zilla::Plugin::PromptIfStale - Check at build/release time if modules are
 
 =head1 VERSION
 
-version 0.040
+version 0.041
 
 =head1 SYNOPSIS
 
